================
healthyhouse-api
================


.. image:: https://img.shields.io/pypi/v/healthyhouse_api.svg
        :target: https://pypi.python.org/pypi/healthyhouse_api

.. image:: https://img.shields.io/travis/bsdis/healthyhouse_api.svg
        :target: https://travis-ci.org/bsdis/healthyhouse_api

.. image:: https://readthedocs.org/projects/healthyhouse-api/badge/?version=latest
        :target: https://healthyhouse-api.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A wrapper of the rest API available for ha healthyhouse installation

This software is can be easily installed from pypi using

   $ pip install healthyhouse_api


* Free software: MIT license
* Documentation: https://healthyhouse-api.readthedocs.io.


Features
--------

* TODO

Credits
-------

